==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/SplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
import { SplineAreaSeriesDescription } from "./SplineAreaSeriesDescription";
/**
 * @hidden
 */
export let SplineAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (SplineAreaSeriesDescriptionMetadata.a == null) {
                SplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineAreaSeriesDescriptionMetadata.c(SplineAreaSeriesDescriptionMetadata.a);
            }
            if (a.j(SplineAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(SplineAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            SplineSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineAreaSeriesDescriptionMetadata.b(a);
            a.aa("SplineAreaSeries", () => new SplineAreaSeriesDescription());
            a.z("SplineAreaSeries", SplineAreaSeriesDescriptionMetadata.a);
        }
    }
    SplineAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(SplineAreaSeriesDescriptionMetadata, 'SplineAreaSeriesDescriptionMetadata');
    SplineAreaSeriesDescriptionMetadata.a = null;
    return SplineAreaSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
import { SplineAreaSeriesDescription } from "./SplineAreaSeriesDescription";
/**
 * @hidden
 */
export let SplineAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class SplineAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (SplineAreaSeriesDescriptionMetadata.a == null) {
                SplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SplineAreaSeriesDescriptionMetadata.c(SplineAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(SplineAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(SplineAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            SplineSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            SplineAreaSeriesDescriptionMetadata.b(a);
            a.ac("SplineAreaSeries", () => new SplineAreaSeriesDescription());
            a.ab("SplineAreaSeries", SplineAreaSeriesDescriptionMetadata.a);
        }
    }
    SplineAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(SplineAreaSeriesDescriptionMetadata, 'SplineAreaSeriesDescriptionMetadata');
    SplineAreaSeriesDescriptionMetadata.a = null;
    return SplineAreaSeriesDescriptionMetadata;
})();
